Module: Functio
- Defined in:
- lib/functio.rb,
lib/functio/errors.rb,
lib/functio/version.rb,
lib/functio/function.rb,
lib/functio/expression.rb,
lib/functio/functio_cli.rb,
lib/functio/data_storage.rb,
lib/functio/formatted_num.rb,
lib/functio/function_repository.rb
Overview
– Copyright © 2016 Cassiano Rocha Kuplich
This file is part of Functio.
Functio is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
Functio is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with Functio. If not, see <www.gnu.org/licenses/>. ++
Defined Under Namespace
Classes: DataStorage, DivisionByZeroError, Expression, FormattedNum, FunctioCLI, FunctioError, Function, FunctionRepository, InvalidExpressionError, InvalidFunctionError
Constant Summary collapse
- VERSION =
Functio version
'0.1.1'.freeze